@@ -186,7 +186,7 @@ int cache_dnspacket(void *packet, int len)
 
     if ((cache_onoff == 0) ||
 	(parse_query(&query, packet, len) == NULL) ||
-	(query.flags.b.question == 0) ||
+	(GET_QR(query.flags) == 0) ||
 	(*query.name == 0)) {
 	return (0);
     }
@@ -239,7 +239,7 @@ int cache_lookup(void *packet, int len)
 
     if ((cache_onoff == 0) ||
 	(parse_query(&query, packet, len) == NULL) ||
-	(query.flags.b.question == 1) ||
+	(GET_QR(query.flags) == 1) ||
 	(*query.name == 0) ||
 	(query.class != DNS_CLASS_INET)) {
 	return (0);
