@@ -586,11 +586,10 @@ static int end_assembly(dnsheader_t *x)
     unsigned short int *pkt;
 
     end_rdata(x);
-/*  x->u.b.authorative = 0; */
+/*  SET_AA(x->u, 0); */
 
     pkt = (unsigned short int *) x->packet;
-    // replaced by guido:
-    pkt[1] = htons(x->u.flags);
+    pkt[1] = htons(x->u);
     pkt[2] = htons(x->qdcount);
     pkt[3] = htons(x->ancount);
     pkt[4] = htons(x->nscount);
@@ -614,8 +613,8 @@ static dnsheader_t *begin_assembly(rr_t *query)
      */
 
     x->id = 0;
-    x->u.flags = 0;
-    x->u.b.question = 1;
+    x->u  = 0;
+    SET_QR(x->u, 1);
 
     x->qdcount = 1;
     x->ancount = 0;
@@ -662,7 +661,7 @@ static int compile_dnsrecords(dnsheader_t *x, char *object)
 	x->nscount++;
     }
 
-    if (x->nscount > 0) x->u.b.authorative = 1;
+    if (x->nscount > 0) SET_AA(x->u, 1);
 
     return (0);
 }
@@ -775,7 +774,7 @@ int master_lookup(unsigned char *msg, int len)
     }
 
     if ((parse_query(&query, msg, len) == NULL) ||
-	(query.class != DNS_CLASS_INET  ||  query.flags.b.opcode != 0)) {
+	(query.class != DNS_CLASS_INET  ||  GET_OPCODE(query.flags) != 0)) {
 	return (0);
     }
 
@@ -864,7 +863,7 @@ int master_lookup(unsigned char *msg, int len)
 		rec = dns_lookup(query.name, &last);
 	    }
 
-	    x->u.b.authorative = 1;
+	    SET_AA(x->u, 1);
 	    end_assembly(x);
 
 	    dump_dnspacket("assembled", x->packet, x->len);
@@ -901,7 +900,7 @@ int master_lookup(unsigned char *msg, int len)
 
 	x = begin_assembly(&query);
 	x->ancount = 0;
-	x->u.b.authorative = 1;
+	SET_AA(x->u, 1);
 	end_assembly(x);
 
 	dump_dnspacket("assembled", x->packet, x->len);
@@ -937,14 +936,14 @@ int master_dontknow(unsigned char *msg, int len, unsigned char *answer)
     if (parse_query(&query, msg, len) == NULL) {
 	return (0);
     }
-    else if (query.class != DNS_CLASS_INET  ||  query.flags.b.opcode != 0) {
+    else if (query.class != DNS_CLASS_INET  ||  GET_OPCODE(query.flags) != 0) {
 	return (0);
     }
 
     x = begin_assembly(&query);
     x->ancount = 0;
-    x->u.b.authorative = 0;
-    x->u.b.rcode = 1;
+    SET_AA(x->u, 0);
+    SET_RCODE(x->u, 1);
     end_assembly(x);
 
     dump_dnspacket("assembled", x->packet, x->len);
